Documentation
¶
Overview ¶
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Package config represnets configurations for given system Supported configurations are env as of right now.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Copyright 2025 Deirror. All rights reserved. Use of this source code is governed by a MIT-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶ added in v1.7.22
type Config struct {
ReadMode // Determines the mode in which configuration is read
Resources []resource.Resource // The resources representing the config source
}
Config represents the configuration for the application. It combines a ReadMode, which determines how the configuration is loaded or interpreted, with a Resource, which points to the underlying source of the configuration (e.g., a local path or a remote URI).
func (*Config) WithReadMode ¶ added in v1.7.22
WithReadMode returns a copy of the Config with a new ReadMode.
type MultiConfig ¶
Represents maps of prefixes (e.g. "NEON", "UPSTASH", "WEB", "db", "whatever_you-want") to a set of Configs.
type ReadMode ¶ added in v1.7.22
type ReadMode string
func ParseReadMode ¶ added in v1.7.22
ParseReadMode converts a string to a ReadMode. Case-insensitive.